<?php
class ControllerExtensionPaymentEps extends Controller {
    private $error = array();

    public function index() {
        $this->load->language('extension/payment/eps');

        $this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('setting/setting');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            $this->model_setting_setting->editSetting('payment_eps', $this->request->post);

            $this->session->data['success'] = $this->language->get('text_success');

            $this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true));
        }

        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        if (isset($this->error['user_id'])) {
            $data['error_user_id'] = $this->error['user_id'];
        } else {
            $data['error_user_id'] = '';
        }

        if (isset($this->error['pin'])) {
            $data['error_pin'] = $this->error['pin'];
        } else {
            $data['error_pin'] = '';
        }

        if (isset($this->error['bic'])) {
            $data['error_bic'] = $this->error['bic'];
        } else {
            $data['error_bic'] = '';
        }

        if (isset($this->error['iban'])) {
            $data['error_iban'] = $this->error['iban'];
        } else {
            $data['error_iban'] = '';
        }

        $data['breadcrumbs'] = array();

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_extension'),
            'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true)
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('extension/payment/eps', 'user_token=' . $this->session->data['user_token'], true)
        );

        $data['action'] = $this->url->link('extension/payment/eps', 'user_token=' . $this->session->data['user_token'], true);

        $data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true);

        if (isset($this->request->post['payment_eps_test'])) {
            $data['payment_eps_test'] = $this->request->post['payment_eps_test'];
        } else {
            $data['payment_eps_test'] = $this->config->get('payment_eps_test');
        }

        if (isset($this->request->post['payment_eps_user_id'])) {
            $data['payment_eps_user_id'] = $this->request->post['payment_eps_user_id'];
        } else {
            $data['payment_eps_user_id'] = $this->config->get('payment_eps_user_id');
        }

        if (isset($this->request->post['payment_eps_pin'])) {
            $data['payment_eps_pin'] = $this->request->post['payment_eps_pin'];
        } else {
            $data['payment_eps_pin'] = $this->config->get('payment_eps_pin');
        }

        if (isset($this->request->post['payment_eps_bic'])) {
            $data['payment_eps_bic'] = $this->request->post['payment_eps_bic'];
        } else {
            $data['payment_eps_bic'] = $this->config->get('payment_eps_bic');
        }

        if (isset($this->request->post['payment_eps_iban'])) {
            $data['payment_eps_iban'] = $this->request->post['payment_eps_iban'];
        } else {
            $data['payment_eps_iban'] = $this->config->get('payment_eps_iban');
        }

        if (isset($this->request->post['payment_eps_order_status_id'])) {
            $data['payment_eps_order_status_id'] = $this->request->post['payment_eps_order_status_id'];
        } else {
            $data['payment_eps_order_status_id'] = $this->config->get('payment_eps_order_status_id');
        }

        if (isset($this->request->post['payment_eps_cancel_order_status_id'])) {
            $data['payment_eps_cancel_order_status_id'] = $this->request->post['payment_eps_cancel_order_status_id'];
        } else {
            $data['payment_eps_cancel_order_status_id'] = $this->config->get('payment_eps_cancel_order_status_id');
        }

        $this->load->model('localisation/order_status');

        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();
        $data['cancel_order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        if (isset($this->request->post['payment_eps_geo_zone_id'])) {
            $data['payment_eps_geo_zone_id'] = $this->request->post['payment_eps_geo_zone_id'];
        } else {
            $data['payment_eps_geo_zone_id'] = $this->config->get('payment_eps_geo_zone_id');
        }

        $this->load->model('localisation/geo_zone');

        $data['geo_zones'] = $this->model_localisation_geo_zone->getGeoZones();

        if (isset($this->request->post['payment_eps_status'])) {
            $data['payment_eps_status'] = $this->request->post['payment_eps_status'];
        } else {
            $data['payment_eps_status'] = $this->config->get('payment_eps_status');
        }

        if (isset($this->request->post['payment_eps_sort_order'])) {
            $data['payment_eps_sort_order'] = $this->request->post['payment_eps_sort_order'];
        } else {
            $data['payment_eps_sort_order'] = $this->config->get('payment_eps_sort_order');
        }

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/payment/eps', $data));
    }

    protected function validate() {
        if (!$this->user->hasPermission('modify', 'extension/payment/eps')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        if (!$this->request->post['payment_eps_user_id']) {
            $this->error['user_id'] = $this->language->get('error_user_id');
        }

        if (!$this->request->post['payment_eps_pin']) {
            $this->error['pin'] = $this->language->get('error_pin');
        }

        if (!$this->request->post['payment_eps_bic']) {
            $this->error['bic'] = $this->language->get('error_bic');
        }

        if (!$this->request->post['payment_eps_iban']) {
            $this->error['iban'] = $this->language->get('error_iban');
        }

        return !$this->error;
    }
}