<?php
use at\externet\eps_bank_transfer;

class ControllerExtensionPaymentEps extends Controller
{
    public function index()
    {
        $data['button_confirm'] = $this->language->get('button_confirm');

        $this->load->model('checkout/order');

        $order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);

        $userID = $this->config->get('payment_eps_user_id');
        $pin    = $this->config->get('payment_eps_pin');
        $bic    = $this->config->get('payment_eps_bic');
        $iban   = $this->config->get('payment_eps_iban');

        if($this->config->get('payment_eps_test') == 1) {
            $targetUrl = 'https://routing.eps.or.at/appl/epsSO-test/transinit/eps/v2_5';
        } else {
            $targetUrl = 'https://routing.eps.or.at/appl/epsSO/transinit/eps/v2_5';
        }

        $confirmUrl = $this->url->link('extension/payment/eps/callback', '', true);
        $successUrl = $this->url->link('extension/payment/eps/success', '', true);
        $failUrl = $this->url->link('extension/payment/eps/fail', '', true);

        $transferMsgDetails = new eps_bank_transfer\TransferMsgDetails(
            $confirmUrl,
            $successUrl,
            $failUrl
        );

        if($order_info['currency_code'] == 'EUR') {
        	$orderTotalEur = round((float)$order_info['total']*(float)$order_info['currency_value'],2);
        	$orderTotal = intval($orderTotalEur*100);
        } else {
        	$orderTotal = intval($order_info['total']*100);
        }

        $transferInitiatorDetails = new eps_bank_transfer\TransferInitiatorDetails(
            $userID,
            $pin,
            $bic,
            $order_info['payment_firstname'] . ' ' . $order_info['payment_lastname'],
            $iban,
            $this->session->data['order_id'],
            $orderTotal,
            $transferMsgDetails
        );

        $transferInitiatorDetails->RemittanceIdentifier = $this->session->data['order_id'];
        $transferInitiatorDetails->SetExpirationMinutes(60);

        $products = $this->cart->getProducts();
        foreach ($products as $product) {
            $article = new eps_bank_transfer\WebshopArticle(
                $product['name'],
                $product['quantity'],
                intval($product['price']*100)
            );
            $transferInitiatorDetails->WebshopArticles[] = $article;
        }

        $soCommunicator = new eps_bank_transfer\SoCommunicator();

        $plain = $soCommunicator->SendTransferInitiatorDetails($transferInitiatorDetails, $targetUrl);
        $xml = new \SimpleXMLElement($plain);
        $soAnswer = $xml->children(eps_bank_transfer\XMLNS_epsp);
        $errorDetails = $soAnswer->BankResponseDetails->ErrorDetails;

        if (('' . $errorDetails->ErrorCode) != '000')
        {
            $errorCode = '' . $errorDetails->ErrorCode;
            $errorMsg = '' . $errorDetails->ErrorMsg;

            echo '<h2>Sorry you can not confirm order, error message: ' . $errorMsg . '</h2>';
            echo '<br>';
            echo '<h2>Error code: ' . $errorCode . '</h2><br>';
        }
        else
        {
            $data['redirect'] = $soAnswer->BankResponseDetails->ClientRedirectUrl->__toString();
            return $this->load->view('extension/payment/eps', $data);
        }
    }

    public function callback()
    {
        $soCommunicator = new eps_bank_transfer\SoCommunicator();

        $soCommunicator->HandleConfirmationUrl(
            [$this, 'paymentConfirmation'],
            null,
            'php://input',
            'php://output'
        );
    }

    public function paymentConfirmation($plainXml, $bankConfirmationDetails)
    {
    	$this->load->model('checkout/order');

        if ($bankConfirmationDetails->GetStatusCode() == 'OK')
        {
            $this->model_checkout_order->addOrderHistory($bankConfirmationDetails->GetRemittanceIdentifier(), $this->config->get('payment_eps_order_status_id'));
        }
        elseif ($bankConfirmationDetails->GetStatusCode() == 'NOK')
        {
            $this->model_checkout_order->addOrderHistory($bankConfirmationDetails->GetRemittanceIdentifier(), $this->config->get('payment_eps_cancel_order_status_id'));
        }

        return true;
    }

    public function fail()
    {
        $errorCode = $this->request->get['epserrorcode'];
        $error_message = $this->getErrorMsg($errorCode);
        
        $data['breadcrumbs'] = array();
        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/home')
        );

        $data['text_message'] = sprintf($error_message, $errorCode, $this->url->link('information/contact'));

        $data['continue'] = $this->url->link('checkout/cart');

        $data['column_left'] = $this->load->controller('common/column_left');
        $data['column_right'] = $this->load->controller('common/column_right');
        $data['content_top'] = $this->load->controller('common/content_top');
        $data['content_bottom'] = $this->load->controller('common/content_bottom');
        $data['footer'] = $this->load->controller('common/footer');
        $data['header'] = $this->load->controller('common/header');
        $this->response->setOutput($this->load->view('common/success', $data));
    }

    public function success()
    {
        $this->response->redirect($this->url->link('checkout/success'));
    }

    private function getErrorMsg($errorCode)
    {
        $this->load->language('extension/payment/eps');
        $errors = array(
            'ERROR1' => $this->language->get('text_error1'),
            'ERROR2' => $this->language->get('text_error2'),
            'ERROR3' => $this->language->get('text_error3')
        );
        return $errors[$errorCode];
    }

}